@@ -4,7 +4,7 @@ use warnings;
 
 use Test2::IPC;
 
-our $VERSION = '0.000004';
+our $VERSION = '0.000005';
 
 our @CARP_NOT = qw/Test2::Util::HashBase/;
 
@@ -59,7 +59,12 @@ sub init {
 
     unless($self->{+HUB}) {
         my $ipc = Test2::API::test2_ipc();
-        my $hub = Test2::AsyncSubtest::Hub->new(format => undef, ipc => $ipc);
+        my $args = delete $self->{hub_init_args} || {};
+        my $hub = Test2::AsyncSubtest::Hub->new(
+            %$args,
+            format => undef,
+            ipc => $ipc,
+        );
         $self->{+HUB} = $hub;
     }
 
